<?php
/* ---------------------------------------------------------------------------
* Soundfaith setting page
* --------------------------------------------------------------------------- */
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
if ( ! class_exists( 'soundfaith_setting_page' ) ) :
	class soundfaith_setting_page {
		private $all_response;

		function __construct() 
        {
			// Runs when the plugin is activated
			add_action( 'admin_menu', array( $this, 'register_soundfaith_submenu_page' ) );

			//Enqueue admin script
			add_action( 'admin_enqueue_scripts', array( &$this,'soundfaith_admin_enqueue_scripts') );

			//Enqueue General script
			add_action( 'wp_enqueue_scripts',array(&$this, 'soundfaith_register_scripts'),999 );

			//Admin Message when plugin needs to be authorized by Soundfaith.com
			add_action( 'admin_notices', array(&$this,'soundfaith_showAdminMessages') );

			/*-----------------------------------------------------------------------------------*/
			/* Save Data for Api Key */
			/*-----------------------------------------------------------------------------------*/
			if(isset($_REQUEST['update_soundfaith_settings']))
			{ 
				if ( !isset($_POST['soundfaith_nonce']) || !wp_verify_nonce($_POST['soundfaith_nonce'],'soundfaith_api_key_nonce_setting') )
				{
					_e('Sorry, your nonce did not verify.', 'soundfaith');
				   exit;
				}
				else
				{
					$soundfaith_group_id_user = sanitize_text_field( $_POST[ 'soundfaith_group_id' ] );
					$soundfaith_sermon_choice = sanitize_text_field( $_POST[ 'soundfaith_sermon_choice' ] );

					if(!empty($soundfaith_group_id_user))
					{
						$api_groupid_url="https://accountsapi.logos.com/v2/groups/".$soundfaith_group_id_user;
						$api_userid_url="https://accountsapi.logos.com/v2/users/".$soundfaith_group_id_user;

						$result_group_id = wp_remote_retrieve_body( wp_remote_get( $api_groupid_url , array( 'timeout' => 18 , 'sslverify' => false ) ) );
						$result_user_id = wp_remote_retrieve_body( wp_remote_get( $api_userid_url , array( 'timeout' => 18 , 'sslverify' => false ) ) );

						$get_group_data = json_decode($result_group_id);
						$get_user_data = json_decode($result_user_id);

						$check_soundfaith_group_id='';
						if(isset($get_group_data->groupId))
						{
							$check_soundfaith_group_id=$get_group_data->groupId;
							$check_soundfaith_group_name=$get_group_data->name;
						}
						else if(isset($get_user_data->id))
						{
							$check_soundfaith_group_id=$get_user_data->id;
						}

						if ($check_soundfaith_group_id)
						{
							update_option('soundfaith_group_id',$soundfaith_group_id_user);
							update_option('soundfaith_group_name',$check_soundfaith_group_name);
							$this->all_response= '<div class="notice notice-success is-dismissible"><p><strong>Valid SoundFaith Group/User ID is entered.</strong></p></div>';
						}
						else
						{
							//update_option('soundfaith_group_id','');
							$this->all_response= '<div class="notice notice-error is-dismissible"><p><strong>Invalid SoundFaith Group/User ID is entered.</strong></p></div>';
						} 
					}
					else
					{
						update_option('soundfaith_group_id','');
					}
					
					if(!isset($soundfaith_sermon_choice))
					{
						$soundfaith_sermon_choice = 0;
					}
					update_option('soundfaith_sermon_choice',$soundfaith_sermon_choice);
					
				}
			}
		}
		/*-----------------------------------------------------------------------------------*/
		/* create admin menu in dashboard
		/*-----------------------------------------------------------------------------------*/
		function register_soundfaith_submenu_page() 
		{
			add_menu_page( __( 'SoundFaith', 'soundfaith' ), __( 'SoundFaith', 'soundfaith' ), 'manage_options', 'soundfaith-settings', array( $this, 'soundfaith_settings' ),'dashicons-lightbulb' );
		}

		/*-----------------------------------------------------------------------------------
		* Function : soundfaith_settings
		* soundfaith general setting pages
		*-----------------------------------------------------------------------------------*/
		function soundfaith_settings() 
		{	
			$option_soundfaith_group_id = get_option( 'soundfaith_group_id' ) ;
			$option_sermon_choice = get_option( 'soundfaith_sermon_choice' ) ? get_option( 'soundfaith_sermon_choice' ) : 1 ;
			$soundfaith_group_name = get_option( 'soundfaith_group_name' ) ? get_option( 'soundfaith_group_name' ) : 0 ;
			?>
			<div class="wrap">
				<h2><?php _e( 'Default Settings','soundfaith' );?></h2>
				<?php _e($this->all_response, 'soundfaith' ); ?>
				<form  method="post" action="">
					<div class="configuration-field">
						<label>
							Account ID
							<input type="text" id="selected_group" name="soundfaith_group_id" value="<?php if(!empty($option_soundfaith_group_id))
					{ echo $option_soundfaith_group_id ; } ?>"/>
						</label>
						<?php wp_nonce_field( 'soundfaith_api_key_nonce_setting', 'soundfaith_nonce' ); ?>
						<p class="submit">
							<input id="soundfaith-submit" class="button-primary" type="submit" name="update_soundfaith_settings" value="<?php _e( 'Save Changes', 'soundfaith' ) ?>" />
						</p>
					</div> 
				</form>
			</div>
			<div class="wrap">
				<h2><?php _e( 'Shortcode Generator','soundfaith' );?></h2>
				<form method="post" action="">
					<div id="soundfaith-shortcode" style="width:50%;float:left">
						<div class="configuration-field">
							<label>
								<?php _e( 'Width','soundfaith' );?>
								<input type="text" name="soundfaith-iframe-width-shortcode" value="640" size="6"/>
							</label>
						</div>
						<div class="configuration-field">
							<label>
								<?php _e( 'Height','soundfaith' );?>
								<input type="text" name="soundfaith-iframe-height-shortcode" value="646" size="6"/>
							</label>
						</div>
						<div class="configuration-field">
							<label>
								Account ID
								<input type="search" id="soundfaith-iframe-account-id-shortcode" name="soundfaith-iframe-account-id-shortcode" size="10" value="<?php if(!empty($option_soundfaith_group_id))
					{ echo $option_soundfaith_group_id ; } ?>"/>
							</label>
						</div>
						<div class="configuration-field">
							<label>
								<input type="checkbox" name="soundfaith-include-playlist-shortcode" id="soundfaith-include-playlist-shortcode" checked="checked" value="true" />
								<?php _e( 'Show playlist','soundfaith' );?>
							</label>
						</div>
						<div class="configuration-field">
							<div>
								<label>
									&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="soundfaith-include-speaker-shortcode" checked="checked" value="true" />
									<?php _e( 'Show speaker name ','soundfaith' );?>
								</label>
							</div>
							<div>
								<label>
									&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="soundfaith-include-series-shortcode" checked="checked" value="true" />
									<?php _e( 'Show series title ','soundfaith' );?>
								</label>
							</div>
							<div>
								<label>
									&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<input type="checkbox" name="soundfaith-include-date-presented-shortcode" checked="checked" value="true" />
									<?php _e( 'Show date','soundfaith' );?>
								</label>
							</div>
						</div>
						<p class="submit">
							<input id="soundfaith_generate_shortcode" class="button-primary" type="button" name="soundfaith_generate_shortcode" value="<?php _e( 'Generate', 'soundfaith' ) ?>" />
							<input id="soundfaith_reset_shortcode" class="button-primary" type="button" name="soundfaith_reset_shortcode" value="<?php _e( 'Reset', 'soundfaith' ) ?>" />
						</p>

						<div id="generated_code">
							<?php _e( 'Shortcode','soundfaith' );?></th>
							<textarea id="generated_code_textarea" rows="5"></textarea><br/><br/>
							<a href="javascript:;" class="button-primary" id="copyButton">Copy Shortcode</a>
						</div>
					</div>
					<div style="width:50%;float:right">
						<div id="soundfaith_iframe_preview_content">
							<input type="hidden" id="soundfaith_iframe_preview_group_id" name="soundfaith_iframe_preview_group_id" value="<?php echo $option_soundfaith_group_id ;  ?>"/>
							<iframe id="soundfaith_iframe_preview" frameborder="0" scrolling="no" allowfullscreen src="https://soundfaith.com/embed/profile/<?php echo $option_soundfaith_group_id ; ?>/recent?includePlaylist=false&scroll=true&includeSpeaker=false&includeSeries=false&includeDatePresented=false" width="80%" height="646"></iframe>
						</div>
					</div>
				</form>
			</div>
		<?php
		}

		/*-----------------------------------------------------------------------------------
		*Bring in needed scripts and files  
		*-----------------------------------------------------------------------------------*/
		function soundfaith_admin_enqueue_scripts() 
		{
			wp_enqueue_script('soundfaith-custom', SOUNDFAITH_PLUGIN_URL .'js/custom.js', false, SOUNDFAITH_PLUGIN_VERSION, true );
			wp_localize_script( 'soundfaith-custom', 'ajaxvariation', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ), 'MEDIA_PATH' => SOUNDFAITH_PLUGIN_URL.'/images/'));
			wp_enqueue_style('soundfaith-admin-css', SOUNDFAITH_PLUGIN_URL .'css/admin.css', false, SOUNDFAITH_PLUGIN_VERSION,'all' );
		}

		/*-----------------------------------------------------------------------------------*/
		/* Bring in needed scripts and files  */
		/*-----------------------------------------------------------------------------------*/
		function soundfaith_register_scripts() 
		{
			wp_enqueue_style('style-css', SOUNDFAITH_PLUGIN_URL.'css/style.css',false, SOUNDFAITH_PLUGIN_VERSION,'all');
		}

		/*-----------------------------------------------------------------------------------*/
		/* Admin Message when plugin needs to be authorized by Soundfaith.com 
		/*-----------------------------------------------------------------------------------*/
		function soundfaith_showAdminMessages() 
		{
		}
	}

	new soundfaith_setting_page;
endif;
